@@ -14,10 +14,10 @@ class TestSBox:
         pbox = SBox(td, camel_killer_box=True)
         assert isinstance(pbox.inner, SBox)
         assert pbox.inner.camel_case == 'Item'
-        assert json.loads(pbox.json)['inner']['CamelCase'] == 'Item'
+        assert json.loads(pbox.json)['inner']['camel_case'] == 'Item'
         test_item = yaml.load(pbox.yaml, Loader=yaml.SafeLoader)
-        assert test_item['inner']['CamelCase'] == 'Item'
+        assert test_item['inner']['camel_case'] == 'Item'
         assert repr(pbox['inner']).startswith('<ShorthandBox')
         assert not isinstance(pbox.dict, Box)
-        assert pbox.dict['inner']['CamelCase'] == 'Item'
+        assert pbox.dict['inner']['camel_case'] == 'Item'
         assert pbox.toml.startswith('key1 = "value1"')
